@@ -63,7 +63,9 @@ func providerImporterSubcommands() []func(options ImportOptions) *cobra.Command
 		newCmdNs1Importer,
 		newCmdPanosImporter,
 		// VCS
+		newCmdAzureDevOpsImporter,
 		newCmdGithubImporter,
+		newCmdGitLabImporter,
 		// Monitoring & System Management
 		newCmdDatadogImporter,
 		newCmdNewRelicImporter,
@@ -77,6 +79,7 @@ func providerImporterSubcommands() []func(options ImportOptions) *cobra.Command
 		newCmdXenorchestraImporter,
 		newCmdGmailfilterImporter,
 		newCmdVaultImporter,
+		newCmdOktaImporter,
 	}
 }
 
@@ -106,7 +109,9 @@ func providerGenerators() map[string]func() terraformutils.ProviderGenerator {
 		// Network
 		newCloudflareProvider,
 		// VCS
+		newAzureDevOpsProvider,
 		newGitHubProvider,
+		newGitLabProvider,
 		// Monitoring & System Management
 		newDataDogProvider,
 		newNewRelicProvider,
@@ -119,6 +124,7 @@ func providerGenerators() map[string]func() terraformutils.ProviderGenerator {
 		newXenorchestraProvider,
 		newGmailfilterProvider,
 		newVaultProvider,
+		newOktaProvider,
 	} {
 		list[providerGen().GetName()] = providerGen
 	}
